@@ -338,7 +338,7 @@ class TestEscapeWikiTableMarkup(ParserTestCase):
         self.do(test)
 
     def do(self, test):
-        expected = r'&lt;tablewidth=&quot;80&quot;&gt;'
+        expected = r'&lt;tablewidth="80"&gt;'
         result = self.parse(test)
         assert re.search(expected, result)
 
@@ -442,7 +442,9 @@ pattern = re.compile(r'{{{This is some nested text}}}')
 }}}}"""
         output = self.parse(raw)
         output = ''.join(output)
-        assert "{{{This is some nested text}}}" in output
+        print output
+        # note: recent pygments renders the opening {{{ intermixed into some <span> tags
+        assert "This is some nested text}}}" in output
 
     def testNestingPreBrackets(self):
         """ tests nested {{{ }}} for the wiki parser
@@ -502,10 +504,10 @@ class TestLinkingMarkup(ParserTestCase):
         ('[[../something]]', '<a class="nonexistent" href="/something">../something</a>'),
         ('[[/something]]', '<a class="nonexistent" href="/%s/something">/something</a>' % PAGENAME),
         ('[[something#anchor]]', '<a class="nonexistent" href="/something#anchor">something#anchor</a>'),
-        ('MoinMoin:something', '<a class="interwiki" href="http://moinmo.in/something" title="MoinMoin">something</a>'),
-        ('[[MoinMoin:something|some text]]', '<a class="interwiki" href="http://moinmo.in/something" title="MoinMoin">some text</a>'),
-        ('[[MoinMoin:with space]]', '<a class="interwiki" href="http://moinmo.in/with%20space" title="MoinMoin">with space</a>'),
-        ('[[MoinMoin:with space|some text]]', '<a class="interwiki" href="http://moinmo.in/with%20space" title="MoinMoin">some text</a>'),
+        ('MoinMoin:something', '<a class="interwiki" href="https://moinmo.in/something" title="MoinMoin">something</a>'),
+        ('[[MoinMoin:something|some text]]', '<a class="interwiki" href="https://moinmo.in/something" title="MoinMoin">some text</a>'),
+        ('[[MoinMoin:with space]]', '<a class="interwiki" href="https://moinmo.in/with%20space" title="MoinMoin">with space</a>'),
+        ('[[MoinMoin:with space|some text]]', '<a class="interwiki" href="https://moinmo.in/with%20space" title="MoinMoin">some text</a>'),
         # no interwiki:
         ('[[ABC:n]]', '<a class="nonexistent" href="/ABC%3An">ABC:n</a>'), # finnish/swedish abbreviations / possessive
         ('ABC:n', 'ABC:n'), # finnish/swedish abbreviations / possessive
